Backlash

Struct Backlash 

pub struct Backlash<T>
where T: Default,
{ /* private fields */ }
Backlash processor.

Implementations

Source

impl<T> Backlash<T>
where T: Default + Copy + PartialEq + PartialOrd + Add<Output = T> + Sub<Output = T> + Div<Output = T> + From<u8>,

pub fn new(deadband_width: T) -> Self

Returns a new instance.

pub fn update(&mut self, value: T) -> T

Processes a new input and returns the output value.

pub fn set_value(&mut self, value: T)

Sets a new output value without any processing.

pub fn value(&self) -> T

Returns the last output value.

pub fn set_deadband_width(&mut self, deadband_width: T)

Sets a new deadband width and centers the borders around the last output value.

pub fn deadband_width(&self) -> T

Returns the deadband width.

pub fn borders(&self) -> (T, T)

Returns the deadband borders as tuple of (lower, upper).

pub fn center_borders(&mut self, value: T)

Center the deadband borders around a specific value.